Document

Exhibit 21

Name of Company |  | Jurisdiction of Incorporation
6570 Donlon Group, LLC |  | Delaware
A & M Products Manufacturing Company |  | Delaware
Andover Properties, Inc. |  | Delaware
Iodine Holdings, Inc. |  | Connecticut
Brita Canada Corporation |  | Nova Scotia
Brita Canada Holdings Corporation |  | Nova Scotia
Brita GP |  | Ontario
Brita LP |  | Ontario
Brita Manufacturing Company |  | Delaware
The Brita Products Company |  | Delaware
BGP (Switzerland) S. a. r. l. |  | Switzerland
Burt’s Bees, Inc. |  | Delaware
Burt’s Bees International Holdings |  | Delaware
Burt’s Bees Licensing, LLC |  | Delaware
The Burt’s Bees Products Company |  | Delaware
Caltech Industries, Inc. |  | Michigan
CBee (Europe) Limited |  | United Kingdom
Chesapeake Assurance Limited |  | Hawaii
Clorox Africa (Proprietary) Ltd. |  | South Africa
Clorox Africa Holdings (Proprietary) Ltd. |  | South Africa
Clorox Argentina S.A. |  | Argentina
Clorox Australasia Holdings, Inc. |  | Delaware
Clorox Australia Pty. Ltd. |  | Australia
Clorox Brazil Holdings LLC |  | Delaware
Clorox (Cayman Islands) Ltd. |  | Cayman Islands
Clorox Chile S.A. |  | Chile
Clorox China (Guangzhou) Ltd. |  | Guangzhou, P.R.C.
Clorox Commercial Company |  | Delaware
The Clorox Company of Canada Ltd. |  | Canada (Federal)
Clorox de Centro America, S.A. |  | Costa Rica
Clorox de Colombia S.A. |  | Colombia
Clorox de Mexico, S de RL de C.V. |  | Mexico
Clorox de Panama S.A. |  | Panama
Clorox del Ecuador S.A. Ecuaclorox |  | Ecuador
Clorox Diamond Production Company |  | Delaware
Clorox Dominicana S.R.L. |  | Dominican Republic
Clorox Healthcare Holdings, LLC |  | Delaware
Clorox Holdings Pty. Limited |  | Australia
Clorox Hong Kong Limited |  | Hong Kong
Clorox Hungary Liquidity Management Kft |  | Hungary
The Clorox International Company |  | Delaware
Clorox International Holdings, LLC |  | Delaware
Clorox International Philippines, Inc. |  | The Philippines
Clorox Luxembourg S.a.r.l. |  | Luxembourg
Clorox (Malaysia) Sdn. Bhd. |  | Malaysia
Clorox Manufacturing Company |  | Delaware
Clorox Manufacturing Company of Puerto Rico, Inc. |  | Puerto Rico

Clorox Mexico Services Company S.A. de C.V. |  | Mexico
Clorox New Zealand Limited |  | New Zealand
The Clorox Outdoor Products Company |  | Delaware
Clorox Peru S.A. |  | Peru
The Clorox Pet Products Company |  | Texas
Clorox Professional Products Company |  | Delaware
The Clorox Sales Company |  | Delaware
Clorox Services Company |  | Delaware
Clorox Spain, S.L. |  | Spain
Clorox Spain Holdings, S.L. |  | Spain
Clorox Sub-Sahara Africa Limited |  | Kenya
Clorox (Switzerland) S.a.r.l. |  | Switzerland
Clorox Uruguay S.A. |  | Uruguay
The Consumer Learning Center, LLC |  | Delaware
Corporacion Clorox de Venezuela, S.A. |  | Venezuela
CLX Realty Co. |  | Delaware
Everest NeoCell LLC |  | Delaware
Evolution Sociedad S.A. |  | Uruguay
Fabricante de Productos Plasticos, S.A. de C.V. |  | Mexico
First Brands (Bermuda) Limited |  | Bermuda
First Brands Corporation |  | Delaware
First Brands do Brasil Ltda. |  | Brazil
Fully Will Limited |  | Hong Kong
Gazoontite, LLC |  | Delaware
Glad Manufacturing Company |  | Delaware
The Glad Products Company |  | Delaware
The Household Cleaning Products Company of Egypt Ltd. |  | Egypt
The HV Food Products Company |  | Delaware
HV Manufacturing Company |  | Delaware
Invermark S.A. |  | Argentina
Jingles LLC |  | Delaware
Kaflex S.A. |  | Argentina
Kingsford Manufacturing Company |  | Delaware
The Kingsford Products Company, LLC |  | Delaware
Lerwood Holdings Limited |  | British Virgin Islands
The Mexco Company |  | Delaware
Mohamed Ali Abudawood for Industry and Partners for Industry Company Ltd. |  | Kingdom of Saudi Arabia
National Cleaning Products Company Limited |  | Kingdom of Saudi Arabia
Nature’s Products, Inc. |  | Florida
Nutranext, LLC |  | Delaware
Nutranext Business, LLC |  | Delaware
Nutranext Direct, LLC |  | Delaware
Paulsboro Packaging Inc. |  | New Jersey
Petroplus Productos Automotivos S.A. |  | Brazil
Petroplus Sul Comercio Exterior S.A. |  | Brazil
Rainbow Light Nutritional Systems, LLC |  | Delaware
ReNew Life Formulas, LLC |  | Delaware
ReNew Life Holdings Corporation |  | Delaware

Round Ridge Production Company |  | Delaware
Soy Vay Enterprises, Inc. |  | California
STP do Brasil Ltda. |  | Brazil
Yuhan-Clorox Co., Ltd. |  | Korea